@@ -7,6 +7,7 @@ from django.views.generic.base import TemplateView
 from django.views.generic.edit import FormView
 
 from .models import Validation
+from .signals import user_signed_up, user_activated
 from .utils import import_dotted_path
 
 
@@ -48,6 +49,12 @@ class SignUpView(FormView):
 		user = Validation.objects.create_inactive_user(**form.cleaned_data)
 		validation = Validation.objects.create_validation(user)
 
+		user_signed_up.send(
+			sender=self.__class__,
+			user=user,
+			request=self.request
+		)
+
 		validation.send_activation_email(get_current_site(self.request))
 
 		return super(SignUpView, self).form_valid(form)
@@ -64,8 +71,17 @@ class ActivateView(TemplateView):
 	def get(self, request, *args, **kwargs):
 		try:
 			validation = Validation.objects.get(key=kwargs['activation_key'])
+			user = validation.user
+
 			validation.activate_user()
 			validation.delete()
+
+			user_activated.send(
+				sender=self.__class__,
+				user=user,
+				request=request
+			)
+
 			return redirect('signup_activate_complete')
 		except Validation.DoesNotExist:
 			pass
